# python-ggoogle


simple cli utility to search from terminal
***
works only with firefox yet
***
installation
- clone project
- insdtall requirements
- install geckodriver
- make main.py executable
- run ```sudo ln -s /path/to/script /usr/bin/g``` or into any $PATH/
***
usage
- ```g some query``` will open new firefox tab with 'some query' in google search
- ```g -p some query``` will do same but in private tab
- ```g``` will open google search page
***
